cli

package
v1.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2026 License: BSD-3-Clause Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CleanupT added in v1.3.0

func CleanupT(t *testing.T, r *git5.Repository)

func CreateT added in v1.3.0

func CreateT(t *testing.T, tags []string) *git5.Repository

Types

type FakeTagCreator added in v1.4.0

type FakeTagCreator struct {
	Tag semantic.Tag
	Err error
}

func (*FakeTagCreator) CreateTag added in v1.4.0

func (f *FakeTagCreator) CreateTag(tag semantic.Tag) error

type FakeTagLister added in v1.4.0

type FakeTagLister struct {
	Taxonomy tags.Taxonomy
	Err      error
}

func (*FakeTagLister) ListRepoTags added in v1.4.0

func (f *FakeTagLister) ListRepoTags() (tags.Taxonomy, error)

type FakeTagPusher added in v1.4.0

type FakeTagPusher struct {
	Tag semantic.Tag
	Err error
}

func (*FakeTagPusher) PushTag added in v1.4.0

func (f *FakeTagPusher) PushTag(tag semantic.Tag) error

type TagCreator added in v1.3.0

type TagCreator interface {
	// CreateTag creates the given tag in the repository.
	CreateTag(semantic.Tag) error
}

A TagCreator is used to create git tags.

func NewTagCreator added in v1.3.0

func NewTagCreator(r *git5.Repository) TagCreator

type TagLister added in v1.3.0

type TagLister interface {
	// ListRepoTags lists the tags on a given repository.
	ListRepoTags() (tags.Taxonomy, error)
}

A TagLister is used to list tags associated with the git repository of a Go module.

func NewTagLister added in v1.3.0

func NewTagLister(r *git5.Repository) TagLister

type TagPusher added in v1.3.0

type TagPusher interface {
	// PushTag pushes the given tag to the default remote.
	PushTag(semantic.Tag) error
}

A TagPusher is used to push tags to a remote.

func NewTagPusher added in v1.3.0

func NewTagPusher(r *git5.Repository) TagPusher

Directories

Path Synopsis

Jump to