Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type FakeTagCreator ¶ added in v1.4.0
type FakeTagLister ¶ added in v1.4.0
func (*FakeTagLister) ListRepoTags ¶ added in v1.4.0
func (f *FakeTagLister) ListRepoTags() (tags.Taxonomy, error)
type FakeTagPusher ¶ added in v1.4.0
type TagCreator ¶ added in v1.3.0
type TagCreator interface {
// CreateTag creates the given tag in the repository.
CreateTag(semantic.Tag) error
}
A TagCreator is used to create git tags.
func NewTagCreator ¶ added in v1.3.0
func NewTagCreator(r *git5.Repository) TagCreator
type TagLister ¶ added in v1.3.0
type TagLister interface {
// ListRepoTags lists the tags on a given repository.
ListRepoTags() (tags.Taxonomy, error)
}
A TagLister is used to list tags associated with the git repository of a Go module.
func NewTagLister ¶ added in v1.3.0
func NewTagLister(r *git5.Repository) TagLister
type TagPusher ¶ added in v1.3.0
type TagPusher interface {
// PushTag pushes the given tag to the default remote.
PushTag(semantic.Tag) error
}
A TagPusher is used to push tags to a remote.
func NewTagPusher ¶ added in v1.3.0
func NewTagPusher(r *git5.Repository) TagPusher
Click to show internal directories.
Click to hide internal directories.